@@ -70,15 +70,11 @@ struct _GeditCloseConfirmationDialogPrivate
 	gboolean     disable_save_to_disk;
 };
 
-#define GEDIT_CLOSE_CONFIRMATION_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), \
-							GEDIT_TYPE_CLOSE_CONFIRMATION_DIALOG, \
-							GeditCloseConfirmationDialogPrivate))
-
 #define GET_MODE(priv) (((priv->unsaved_documents != NULL) && \
 			 (priv->unsaved_documents->next == NULL)) ? \
 			  SINGLE_DOC_MODE : MULTIPLE_DOCS_MODE)
 
-G_DEFINE_TYPE(GeditCloseConfirmationDialog, gedit_close_confirmation_dialog, GTK_TYPE_DIALOG)
+G_DEFINE_TYPE_WITH_PRIVATE (GeditCloseConfirmationDialog, gedit_close_confirmation_dialog, GTK_TYPE_DIALOG)
 
 static void 	 set_unsaved_document 		(GeditCloseConfirmationDialog *dlg,
 						 const GList                  *list);
@@ -129,7 +125,7 @@ gedit_close_confirmation_dialog_init (GeditCloseConfirmationDialog *dlg)
 	GeditLockdownMask lockdown;
 	AtkObject *atk_obj;
 
-	dlg->priv = GEDIT_CLOSE_CONFIRMATION_DIALOG_GET_PRIVATE (dlg);
+	dlg->priv = gedit_close_confirmation_dialog_get_instance_private (dlg);
 
 	lockdown = gedit_app_get_lockdown (GEDIT_APP (g_application_get_default ()));
 
@@ -226,8 +222,6 @@ gedit_close_confirmation_dialog_class_init (GeditCloseConfirmationDialogClass *k
 	gobject_class->get_property = gedit_close_confirmation_dialog_get_property;
 	gobject_class->finalize = gedit_close_confirmation_dialog_finalize;
 
-	g_type_class_add_private (klass, sizeof (GeditCloseConfirmationDialogPrivate));
-
 	g_object_class_install_property (gobject_class,
 					 PROP_UNSAVED_DOCUMENTS,
 					 g_param_spec_pointer ("unsaved_documents",
@@ -460,15 +454,17 @@ build_single_doc_dialog (GeditCloseConfirmationDialog *dlg)
 	add_buttons (dlg);
 
 	/* Image */
-	image = gtk_image_new_from_icon_name ("dialog-warning",
+	image = gtk_image_new_from_icon_name ("dialog-warning-symbolic",
 					      GTK_ICON_SIZE_DIALOG);
 	gtk_widget_set_halign (image, GTK_ALIGN_START);
+	gtk_widget_set_valign (image, GTK_ALIGN_START);
 
 	/* Primary label */
 	primary_label = gtk_label_new (NULL);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
 	gtk_widget_set_halign (primary_label, GTK_ALIGN_START);
+	gtk_misc_set_alignment (GTK_MISC (primary_label), 0, 0.5);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 	gtk_widget_set_can_focus (primary_label, FALSE);
 
@@ -476,13 +472,13 @@ build_single_doc_dialog (GeditCloseConfirmationDialog *dlg)
 
 	if (dlg->priv->disable_save_to_disk)
 	{
-		str = g_markup_printf_escaped (_("Changes to document \"%s\" will be permanently lost."),
-					       doc_name);
+		str = g_markup_printf_escaped (_("Changes to document “%s” will be permanently lost."),
+		                               doc_name);
 	}
 	else
 	{
-		str = g_markup_printf_escaped (_("Save changes to document \"%s\" before closing?"),
-					       doc_name);
+		str = g_markup_printf_escaped (_("Save changes to document “%s” before closing?"),
+		                               doc_name);
 	}
 
 	g_free (doc_name);
@@ -495,13 +491,19 @@ build_single_doc_dialog (GeditCloseConfirmationDialog *dlg)
 
 	/* Secondary label */
 	if (dlg->priv->disable_save_to_disk)
+	{
 		str = g_strdup (_("Saving has been disabled by the system administrator."));
+	}
 	else
+	{
 		str = get_text_secondary_label (doc);
+	}
+
 	secondary_label = gtk_label_new (str);
 	g_free (str);
 	gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
 	gtk_widget_set_halign (secondary_label, GTK_ALIGN_START);
+	gtk_misc_set_alignment (GTK_MISC (secondary_label), 0, 0.5);
 	gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
 	gtk_widget_set_can_focus (secondary_label, FALSE);
 
@@ -515,10 +517,7 @@ build_single_doc_dialog (GeditCloseConfirmationDialog *dlg)
 	gtk_box_pack_start (GTK_BOX (vbox), primary_label, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), secondary_label, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
-			    hbox,
-	                    FALSE,
-			    FALSE,
-			    0);
+	                    hbox, FALSE, FALSE, 0);
 
 	gtk_widget_show_all (hbox);
 }
@@ -643,9 +642,10 @@ build_multiple_docs_dialog (GeditCloseConfirmationDialog *dlg)
 			    hbox, TRUE, TRUE, 0);
 
 	/* Image */
-	image = gtk_image_new_from_icon_name ("dialog-warning",
+	image = gtk_image_new_from_icon_name ("dialog-warning-symbolic",
 					      GTK_ICON_SIZE_DIALOG);
 	gtk_widget_set_halign (image, GTK_ALIGN_START);
+	gtk_widget_set_valign (image, GTK_ALIGN_START);
 	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
 
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
@@ -655,8 +655,10 @@ build_multiple_docs_dialog (GeditCloseConfirmationDialog *dlg)
 	primary_label = gtk_label_new (NULL);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
+	gtk_misc_set_alignment (GTK_MISC (primary_label), 0, 0.5);
 	gtk_widget_set_halign (primary_label, GTK_ALIGN_START);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
+	gtk_widget_set_can_focus (primary_label, FALSE);
 
 	if (priv->disable_save_to_disk)
 	{
@@ -688,9 +690,13 @@ build_multiple_docs_dialog (GeditCloseConfirmationDialog *dlg)
 	gtk_box_pack_start (GTK_BOX (vbox), vbox2, FALSE, FALSE, 0);
 
 	if (priv->disable_save_to_disk)
+	{
 		select_label = gtk_label_new_with_mnemonic (_("Docum_ents with unsaved changes:"));
+	}
 	else
+	{
 		select_label = gtk_label_new_with_mnemonic (_("S_elect the documents you want to save:"));
+	}
 
 	gtk_box_pack_start (GTK_BOX (vbox2), select_label, FALSE, FALSE, 0);
 	gtk_label_set_line_wrap (GTK_LABEL (select_label), TRUE);
@@ -721,6 +727,7 @@ build_multiple_docs_dialog (GeditCloseConfirmationDialog *dlg)
 	gtk_box_pack_start (GTK_BOX (vbox2), secondary_label, FALSE, FALSE, 0);
 	gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
 	gtk_widget_set_halign (secondary_label, GTK_ALIGN_START);
+	gtk_misc_set_alignment (GTK_MISC (secondary_label), 0, 0.5);
 	gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
 
 	gtk_label_set_mnemonic_widget (GTK_LABEL (select_label), treeview);
