@@ -135,15 +135,11 @@ static void
 text_not_found (GeditWindow        *window,
 		GeditReplaceDialog *replace_dialog)
 {
-	GtkSourceSearchSettings *search_settings;
 	const gchar *search_text;
-	gchar *escaped_search_text;
 	gchar *truncated_text;
 
-	search_settings = gedit_replace_dialog_get_search_settings (replace_dialog);
-	search_text = gtk_source_search_settings_get_search_text (search_settings);
-	escaped_search_text = gtk_source_utils_escape_search_text (search_text);
-	truncated_text = gedit_utils_str_end_truncate (escaped_search_text, MAX_MSG_LENGTH);
+	search_text = gedit_replace_dialog_get_search_text (replace_dialog);
+	truncated_text = gedit_utils_str_end_truncate (search_text, MAX_MSG_LENGTH);
 
 	gedit_statusbar_flash_message (GEDIT_STATUSBAR (window->priv->statusbar),
 				       window->priv->generic_message_cid,
@@ -151,7 +147,6 @@ text_not_found (GeditWindow        *window,
 				          entered by the user in the search box */
 				       _("\"%s\" not found"), truncated_text);
 
-	g_free (escaped_search_text);
 	g_free (truncated_text);
 }
 
@@ -173,10 +168,6 @@ finish_search_from_dialog (GeditWindow *window,
 	{
 		text_not_found (window, replace_dialog);
 	}
-
-	gtk_dialog_set_response_sensitive (GTK_DIALOG (replace_dialog),
-					   GEDIT_REPLACE_DIALOG_REPLACE_RESPONSE,
-					   found);
 }
 
 static gboolean
@@ -403,33 +394,6 @@ do_find (GeditReplaceDialog *dialog,
 	}
 }
 
-/* FIXME: move in gedit-document.c and share it with gedit-view-frame */
-static gboolean
-get_selected_text (GtkTextBuffer  *doc,
-		   gchar         **selected_text,
-		   gint           *len)
-{
-	GtkTextIter start, end;
-
-	g_return_val_if_fail (selected_text != NULL, FALSE);
-	g_return_val_if_fail (*selected_text == NULL, FALSE);
-
-	if (!gtk_text_buffer_get_selection_bounds (doc, &start, &end))
-	{
-		if (len != NULL)
-			len = 0;
-
-		return FALSE;
-	}
-
-	*selected_text = gtk_text_buffer_get_slice (doc, &start, &end, TRUE);
-
-	if (len != NULL)
-		*len = g_utf8_strlen (*selected_text, -1);
-
-	return TRUE;
-}
-
 static void
 do_replace (GeditReplaceDialog *dialog,
 	    GeditWindow        *window)
@@ -440,6 +404,7 @@ do_replace (GeditReplaceDialog *dialog,
 	gchar *unescaped_replace_text;
 	GtkTextIter start;
 	GtkTextIter end;
+	GError *error = NULL;
 
 	doc = gedit_window_get_active_document (window);
 
@@ -467,10 +432,17 @@ do_replace (GeditReplaceDialog *dialog,
 					   &start,
 					   &end,
 					   unescaped_replace_text,
-					   -1);
+					   -1,
+					   &error);
 
 	g_free (unescaped_replace_text);
 
+	if (error != NULL)
+	{
+		gedit_replace_dialog_set_replace_error (dialog, error->message);
+		g_error_free (error);
+	}
+
 	do_find (dialog, window);
 }
 
@@ -483,6 +455,7 @@ do_replace_all (GeditReplaceDialog *dialog,
 	const gchar *replace_entry_text;
 	gchar *unescaped_replace_text;
 	gint count;
+	GError *error = NULL;
 
 	doc = gedit_window_get_active_document (window);
 
@@ -504,7 +477,10 @@ do_replace_all (GeditReplaceDialog *dialog,
 
 	unescaped_replace_text = gtk_source_utils_unescape_search_text (replace_entry_text);
 
-	count = gtk_source_search_context_replace_all (search_context, unescaped_replace_text, -1);
+	count = gtk_source_search_context_replace_all (search_context,
+						       unescaped_replace_text,
+						       -1,
+						       &error);
 
 	g_free (unescaped_replace_text);
 
@@ -512,99 +488,16 @@ do_replace_all (GeditReplaceDialog *dialog,
 	{
 		text_found (window, count);
 	}
-	else
+	else if (error == NULL)
 	{
 		text_not_found (window, dialog);
 	}
 
-	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
-					   GEDIT_REPLACE_DIALOG_REPLACE_RESPONSE,
-					   FALSE);
-}
-
-static void
-update_regex_error (GeditReplaceDialog     *dialog,
-		    GtkSourceSearchContext *search_context)
-{
-	GError *regex_error = gtk_source_search_context_get_regex_error (search_context);
-	GtkSourceRegexSearchState regex_state = gtk_source_search_context_get_regex_state (search_context);
-
-	gedit_replace_dialog_set_search_error (dialog, NULL);
-	gedit_replace_dialog_set_replace_error (dialog, NULL);
-
-	if (regex_error == NULL)
+	if (error != NULL)
 	{
-		return;
+		gedit_replace_dialog_set_replace_error (dialog, error->message);
+		g_error_free (error);
 	}
-
-	switch (regex_state)
-	{
-		case GTK_SOURCE_REGEX_SEARCH_COMPILATION_ERROR:
-		case GTK_SOURCE_REGEX_SEARCH_MATCHING_ERROR:
-			gedit_replace_dialog_set_search_error (dialog, regex_error->message);
-			break;
-
-		case GTK_SOURCE_REGEX_SEARCH_REPLACE_ERROR:
-			gedit_replace_dialog_set_replace_error (dialog, regex_error->message);
-			break;
-
-		default:
-			g_return_if_reached ();
-	}
-
-	g_error_free (regex_error);
-}
-
-static void
-regex_error_notify_cb (GtkSourceSearchContext *search_context,
-		       GParamSpec             *pspec,
-		       GeditReplaceDialog     *dialog)
-{
-	GeditDocument *doc;
-	GtkSourceSearchContext *doc_search_context;
-
-	doc = GEDIT_DOCUMENT (gtk_source_search_context_get_buffer (search_context));
-	doc_search_context = _gedit_document_get_search_context (doc);
-
-	if (search_context == doc_search_context)
-	{
-		update_regex_error (dialog, search_context);
-	}
-}
-
-static void
-search_context_finalized_cb (GeditReplaceDialog *dialog,
-			     GObject            *where_the_object_was)
-{
-	gedit_replace_dialog_set_search_error (dialog, NULL);
-	gedit_replace_dialog_set_replace_error (dialog, NULL);
-}
-
-static void
-create_search_context (GeditReplaceDialog      *dialog,
-		       GeditDocument           *doc,
-		       GtkSourceSearchSettings *search_settings)
-{
-	GtkSourceSearchContext *search_context;
-
-	search_context = gtk_source_search_context_new (GTK_SOURCE_BUFFER (doc),
-							search_settings);
-
-	g_signal_connect_object (search_context,
-				 "notify::regex-error",
-				 G_CALLBACK (regex_error_notify_cb),
-				 dialog,
-				 0);
-
-	g_object_weak_ref (G_OBJECT (search_context),
-			   (GWeakNotify)search_context_finalized_cb,
-			   dialog);
-
-	update_regex_error (dialog, search_context);
-
-	_gedit_document_set_search_context (doc, search_context);
-
-	g_object_unref (search_context);
 }
 
 static void
@@ -612,23 +505,8 @@ replace_dialog_response_cb (GeditReplaceDialog *dialog,
 			    gint                response_id,
 			    GeditWindow        *window)
 {
-	GeditDocument *doc;
-	GtkSourceSearchContext *search_context;
-	GtkSourceSearchSettings *search_settings;
-
 	gedit_debug (DEBUG_COMMANDS);
 
-	search_settings = gedit_replace_dialog_get_search_settings (dialog);
-
-	doc = gedit_window_get_active_document (window);
-	search_context = _gedit_document_get_search_context (doc);
-
-	if (search_context == NULL ||
-	    search_settings != gtk_source_search_context_get_settings (search_context))
-	{
-		create_search_context (dialog, doc, search_settings);
-	}
-
 	switch (response_id)
 	{
 		case GEDIT_REPLACE_DIALOG_FIND_RESPONSE:
@@ -666,9 +544,7 @@ replace_dialog_destroyed (GeditWindow        *window,
 static GtkWidget *
 create_dialog (GeditWindow *window)
 {
-	GtkWidget *dialog;
-
-	dialog = gedit_replace_dialog_new (GTK_WINDOW (window));
+	GtkWidget *dialog = gedit_replace_dialog_new (window);
 
 	g_signal_connect (dialog,
 			  "response",
@@ -712,10 +588,6 @@ _gedit_cmd_search_replace (GtkAction   *action,
 {
 	gpointer data;
 	GtkWidget *replace_dialog;
-	GeditDocument *doc;
-	gboolean selection_exists;
-	gchar *find_text = NULL;
-	gint sel_len;
 
 	gedit_debug (DEBUG_COMMANDS);
 
@@ -732,25 +604,6 @@ _gedit_cmd_search_replace (GtkAction   *action,
 		replace_dialog = GTK_WIDGET (data);
 	}
 
-	doc = gedit_window_get_active_document (window);
-	g_return_if_fail (doc != NULL);
-
-	selection_exists = get_selected_text (GTK_TEXT_BUFFER (doc),
-					      &find_text,
-					      &sel_len);
-
-	if (selection_exists && find_text != NULL && sel_len < 80)
-	{
-		gchar *escaped_find_text = gtk_source_utils_escape_search_text (find_text);
-
-		gedit_replace_dialog_set_search_text (GEDIT_REPLACE_DIALOG (replace_dialog),
-						      escaped_find_text);
-
-		g_free (escaped_find_text);
-	}
-
-	g_free (find_text);
-
 	gtk_widget_show (replace_dialog);
 	last_search_data_restore_position (GEDIT_REPLACE_DIALOG (replace_dialog));
 	gedit_replace_dialog_present_with_time (GEDIT_REPLACE_DIALOG (replace_dialog),
