@@ -33,6 +33,8 @@
 #include "gedit-history-entry.h"
 #include "gedit-document.h"
 
+#define GEDIT_SEARCH_CONTEXT_KEY "gedit-search-context-key"
+
 struct _GeditReplaceDialogPrivate
 {
 	GtkWidget *grid;
@@ -48,8 +50,6 @@ struct _GeditReplaceDialogPrivate
 	GtkWidget *backwards_checkbutton;
 	GtkWidget *wrap_around_checkbutton;
 
-	GtkSourceSearchSettings *search_settings;
-
 	GeditDocument *active_document;
 
 	guint idle_update_sensitivity_id;
@@ -57,22 +57,6 @@ struct _GeditReplaceDialogPrivate
 
 G_DEFINE_TYPE_WITH_PRIVATE (GeditReplaceDialog, gedit_replace_dialog, GTK_TYPE_DIALOG)
 
-static GeditWindow *
-get_gedit_window (GeditReplaceDialog *dialog)
-{
-	GtkWindow *transient_for = gtk_window_get_transient_for (GTK_WINDOW (dialog));
-
-	return transient_for != NULL ? GEDIT_WINDOW (transient_for) : NULL;
-}
-
-static GeditDocument *
-get_active_document (GeditReplaceDialog *dialog)
-{
-	GeditWindow *window = get_gedit_window (dialog);
-
-	return window != NULL ? gedit_window_get_active_document (window) : NULL;
-}
-
 static GtkSourceSearchContext *
 get_search_context (GeditReplaceDialog *dialog,
 		    GeditDocument      *doc)
@@ -87,7 +71,7 @@ get_search_context (GeditReplaceDialog *dialog,
 	search_context = _gedit_document_get_search_context (doc);
 
 	if (search_context != NULL &&
-	    dialog->priv->search_settings == gtk_source_search_context_get_settings (search_context))
+	    g_object_get_data (G_OBJECT (search_context), GEDIT_SEARCH_CONTEXT_KEY) == dialog)
 	{
 		return search_context;
 	}
@@ -95,6 +79,91 @@ get_search_context (GeditReplaceDialog *dialog,
 	return NULL;
 }
 
+/* The search settings between the dialog's widgets (checkbuttons and the text
+ * entry) and the SearchSettings object are not bound. Instead, this function is
+ * called to set the search settings from the widgets to the SearchSettings
+ * object.
+ *
+ * The reason: the search and replace dialog is not an incremental search. You
+ * have to press the buttons to have an effect. The SearchContext is created
+ * only when a button is pressed, not before. If the SearchContext was created
+ * directly when the dialog window is shown, or when the document tab is
+ * switched, there would be a problem. When we switch betweeen tabs to find on
+ * which tab(s) we want to do the search, we may have older searches (still
+ * highlighted) that we don't want to lose, and we don't want the new search to
+ * appear on each tab that we open. Only when we press a button. So when the
+ * SearchContext is not already created, this is not an incremental search. Once
+ * the SearchContext is created, it's better to be consistent, and therefore we
+ * don't want the incremental search: we have to always press a button to
+ * execute the search.
+ *
+ * Likewise, each created SearchContext (from the GeditReplaceDialog) contains a
+ * different SearchSettings. When set_search_settings() is called for one
+ * document tab (and thus one SearchSettings), it doesn't have an effect on the
+ * other tabs. But the dialog widgets don't change.
+ */
+static void
+set_search_settings (GeditReplaceDialog *dialog)
+{
+	GtkSourceSearchContext *search_context;
+	GtkSourceSearchSettings *search_settings;
+	gboolean case_sensitive;
+	gboolean at_word_boundaries;
+	gboolean regex_enabled;
+	gboolean wrap_around;
+	const gchar *search_text;
+
+	search_context = get_search_context (dialog, dialog->priv->active_document);
+
+	if (search_context == NULL)
+	{
+		return;
+	}
+
+	search_settings = gtk_source_search_context_get_settings (search_context);
+
+	case_sensitive = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->match_case_checkbutton));
+	gtk_source_search_settings_set_case_sensitive (search_settings, case_sensitive);
+
+	at_word_boundaries = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->entire_word_checkbutton));
+	gtk_source_search_settings_set_at_word_boundaries (search_settings, at_word_boundaries);
+
+	regex_enabled = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->regex_checkbutton));
+	gtk_source_search_settings_set_regex_enabled (search_settings, regex_enabled);
+
+	wrap_around = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->wrap_around_checkbutton));
+	gtk_source_search_settings_set_wrap_around (search_settings, wrap_around);
+
+	search_text = gtk_entry_get_text (GTK_ENTRY (dialog->priv->search_text_entry));
+
+	if (regex_enabled)
+	{
+		gtk_source_search_settings_set_search_text (search_settings, search_text);
+	}
+	else
+	{
+		gchar *unescaped_search_text = gtk_source_utils_unescape_search_text (search_text);
+		gtk_source_search_settings_set_search_text (search_settings, unescaped_search_text);
+		g_free (unescaped_search_text);
+	}
+}
+
+static GeditWindow *
+get_gedit_window (GeditReplaceDialog *dialog)
+{
+	GtkWindow *transient_for = gtk_window_get_transient_for (GTK_WINDOW (dialog));
+
+	return transient_for != NULL ? GEDIT_WINDOW (transient_for) : NULL;
+}
+
+static GeditDocument *
+get_active_document (GeditReplaceDialog *dialog)
+{
+	GeditWindow *window = get_gedit_window (dialog);
+
+	return window != NULL ? gedit_window_get_active_document (window) : NULL;
+}
+
 void
 gedit_replace_dialog_present_with_time (GeditReplaceDialog *dialog,
 					guint32             timestamp)
@@ -361,10 +430,22 @@ connect_active_document (GeditReplaceDialog *dialog)
 
 	if (search_context == NULL)
 	{
+		GtkSourceSearchSettings *settings = gtk_source_search_settings_new ();
+
 		search_context = gtk_source_search_context_new (GTK_SOURCE_BUFFER (doc),
-								dialog->priv->search_settings);
+								settings);
+
+		/* Mark the search context that it comes from the search and
+		 * replace dialog. Search contexts can be created also from the
+		 * GeditViewFrame.
+		 */
+		g_object_set_data (G_OBJECT (search_context),
+				   GEDIT_SEARCH_CONTEXT_KEY,
+				   dialog);
 
 		_gedit_document_set_search_context (doc, search_context);
+
+		g_object_unref (settings);
 		g_object_unref (search_context);
 	}
 
@@ -385,8 +466,8 @@ connect_active_document (GeditReplaceDialog *dialog)
 }
 
 static void
-gedit_replace_dialog_response (GtkDialog *dialog,
-                               gint       response_id)
+response_cb (GtkDialog *dialog,
+	     gint       response_id)
 {
 	GeditReplaceDialog *dlg = GEDIT_REPLACE_DIALOG (dialog);
 	const gchar *str;
@@ -419,6 +500,7 @@ gedit_replace_dialog_response (GtkDialog *dialog,
 		case GEDIT_REPLACE_DIALOG_REPLACE_ALL_RESPONSE:
 		case GEDIT_REPLACE_DIALOG_FIND_RESPONSE:
 			connect_active_document (GEDIT_REPLACE_DIALOG (dialog));
+			set_search_settings (GEDIT_REPLACE_DIALOG (dialog));
 	}
 }
 
@@ -427,7 +509,6 @@ gedit_replace_dialog_dispose (GObject *object)
 {
 	GeditReplaceDialog *dialog = GEDIT_REPLACE_DIALOG (object);
 
-	g_clear_object (&dialog->priv->search_settings);
 	g_clear_object (&dialog->priv->active_document);
 
 	if (dialog->priv->idle_update_sensitivity_id != 0)
@@ -444,11 +525,9 @@ gedit_replace_dialog_class_init (GeditReplaceDialogClass *klass)
 {
 	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
-	GtkDialogClass *dialog_class = GTK_DIALOG_CLASS (klass);
 
 	gobject_class->dispose = gedit_replace_dialog_dispose;
 	widget_class->delete_event = gedit_replace_dialog_delete_event;
-	dialog_class->response = gedit_replace_dialog_response;
 
 	/* Bind class to template */
 	gtk_widget_class_set_template_from_resource (widget_class,
@@ -467,24 +546,7 @@ static void
 search_text_entry_changed (GtkEditable        *editable,
 			   GeditReplaceDialog *dialog)
 {
-	const gchar *search_text;
-
-	search_text = gtk_entry_get_text (GTK_ENTRY (editable));
-
-	if (gtk_source_search_settings_get_regex_enabled (dialog->priv->search_settings))
-	{
-		gtk_source_search_settings_set_search_text (dialog->priv->search_settings,
-							    search_text);
-	}
-	else
-	{
-		gchar *unescaped_search_text = gtk_source_utils_unescape_search_text (search_text);
-
-		gtk_source_search_settings_set_search_text (dialog->priv->search_settings,
-							    unescaped_search_text);
-
-		g_free (unescaped_search_text);
-	}
+	set_search_error (dialog, NULL);
 
 	update_responses_sensitivity (dialog);
 }
@@ -545,12 +607,6 @@ show_cb (GeditReplaceDialog *dialog)
 		return;
 	}
 
-	g_signal_connect_object (window,
-				 "active-tab-changed",
-				 G_CALLBACK (connect_active_document),
-				 dialog,
-				 G_CONNECT_SWAPPED);
-
 	doc = get_active_document (dialog);
 
 	if (doc == NULL)
@@ -564,9 +620,12 @@ show_cb (GeditReplaceDialog *dialog)
 
 	if (selection_exists && selection != NULL && selection_length < 80)
 	{
+		gboolean regex_enabled;
 		gchar *escaped_selection;
 
-		if (gtk_source_search_settings_get_regex_enabled (dialog->priv->search_settings))
+		regex_enabled = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->regex_checkbutton));
+
+		if (regex_enabled)
 		{
 			escaped_selection = g_regex_escape_string (selection, -1);
 		}
@@ -581,18 +640,12 @@ show_cb (GeditReplaceDialog *dialog)
 		g_free (escaped_selection);
 	}
 
-	connect_active_document (dialog);
-
 	g_free (selection);
 }
 
 static void
 hide_cb (GeditReplaceDialog *dialog)
 {
-	GeditWindow *window = get_gedit_window (dialog);
-
-	g_signal_handlers_disconnect_by_func (window, connect_active_document, dialog);
-
 	disconnect_document (dialog);
 }
 
@@ -653,24 +706,6 @@ gedit_replace_dialog_init (GeditReplaceDialog *dlg)
 			  G_CALLBACK (replace_text_entry_changed),
 			  dlg);
 
-	dlg->priv->search_settings = gtk_source_search_settings_new ();
-
-	g_object_bind_property (dlg->priv->match_case_checkbutton, "active",
-				dlg->priv->search_settings, "case-sensitive",
-				G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
-
-	g_object_bind_property (dlg->priv->entire_word_checkbutton, "active",
-				dlg->priv->search_settings, "at-word-boundaries",
-				G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
-
-	g_object_bind_property (dlg->priv->regex_checkbutton, "active",
-				dlg->priv->search_settings, "regex-enabled",
-				G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
-
-	g_object_bind_property (dlg->priv->wrap_around_checkbutton, "active",
-				dlg->priv->search_settings, "wrap-around",
-				G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
-
 	g_signal_connect (dlg,
 			  "show",
 			  G_CALLBACK (show_cb),
@@ -680,6 +715,14 @@ gedit_replace_dialog_init (GeditReplaceDialog *dlg)
 			  "hide",
 			  G_CALLBACK (hide_cb),
 			  NULL);
+
+	/* We connect here to make sure this handler runs before the others so
+	 * that the search context is created.
+	 */
+	g_signal_connect (dlg,
+			  "response",
+			  G_CALLBACK (response_cb),
+			  NULL);
 }
 
 GtkWidget *
