@@ -39,14 +39,11 @@ enum
 	PROP_LABEL
 };
 
-G_DEFINE_TYPE_WITH_CODE (GeditStatusMenuButton, gedit_status_menu_button, GTK_TYPE_MENU_BUTTON,
-                         g_type_add_class_private (g_define_type_id, sizeof (GeditStatusMenuButtonClassPrivate)))
-
-static void
-gedit_status_menu_button_finalize (GObject *object)
-{
-	G_OBJECT_CLASS (gedit_status_menu_button_parent_class)->finalize (object);
-}
+G_DEFINE_TYPE_WITH_CODE (GeditStatusMenuButton,
+			 gedit_status_menu_button,
+			 GTK_TYPE_MENU_BUTTON,
+			 G_ADD_PRIVATE (GeditStatusMenuButton)
+			 g_type_add_class_private (g_define_type_id, sizeof (GeditStatusMenuButtonClassPrivate)))
 
 static void
 gedit_status_menu_button_get_property (GObject    *object,
@@ -101,7 +98,6 @@ gedit_status_menu_button_class_init (GeditStatusMenuButtonClass *klass)
 		  "padding: 1px 8px 2px 4px;\n"
 		"}";
 
-	object_class->finalize = gedit_status_menu_button_finalize;
 	object_class->get_property = gedit_status_menu_button_get_property;
 	object_class->set_property = gedit_status_menu_button_set_property;
 
@@ -110,9 +106,7 @@ gedit_status_menu_button_class_init (GeditStatusMenuButtonClass *klass)
 	/* Bind class to template */
 	gtk_widget_class_set_template_from_resource (widget_class,
 	                                             "/org/gnome/gedit/ui/gedit-status-menu-button.ui");
-	gtk_widget_class_bind_child (widget_class, GeditStatusMenuButtonPrivate, label);
-
-	g_type_class_add_private (object_class, sizeof (GeditStatusMenuButtonPrivate));
+	gtk_widget_class_bind_template_child_private (widget_class, GeditStatusMenuButton, label);
 
 	klass->priv = G_TYPE_CLASS_GET_PRIVATE (klass, GEDIT_TYPE_STATUS_MENU_BUTTON, GeditStatusMenuButtonClassPrivate);
 
@@ -125,7 +119,7 @@ gedit_status_menu_button_init (GeditStatusMenuButton *self)
 {
 	GtkStyleContext *context;
 
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE(self, GEDIT_TYPE_STATUS_MENU_BUTTON, GeditStatusMenuButtonPrivate);
+	self->priv = gedit_status_menu_button_get_instance_private (self);
 
 	gtk_widget_init_template (GTK_WIDGET (self));
 
