@@ -38,7 +38,7 @@
 #include <atk/atk.h>
 #include <gedit/gedit-encodings.h>
 #include <gedit/gedit-document.h>
-#include <gtksourceview/gtksourceview.h>
+#include <gtksourceview/gtksource.h>
 
 G_BEGIN_DECLS
 
@@ -88,8 +88,10 @@ void		 gedit_utils_set_atk_relation		(GtkWidget        *obj1,
 							 GtkWidget        *obj2,
 							 AtkRelationType   rel_type);
 
+G_DEPRECATED_FOR (gtk_source_utils_escape_search_text)
 gchar		*gedit_utils_escape_search_text		(const gchar      *text);
 
+G_DEPRECATED_FOR (gtk_source_utils_unescape_search_text)
 gchar		*gedit_utils_unescape_search_text	(const gchar      *text);
 
 void		 gedit_warning				(GtkWindow        *parent,
