@@ -1604,7 +1604,7 @@ static const SECTION union { const guint8 data[12758]; const double alignment; v
   0x28, 0x75, 0x75, 0x61, 0x79, 0x29
 } };
 
-static GStaticResource static_resource = { gedit_docinfo_resource_data.data, sizeof (gedit_docinfo_resource_data.data) };
+static GStaticResource static_resource = { gedit_docinfo_resource_data.data, sizeof (gedit_docinfo_resource_data.data), NULL, NULL, NULL };
 extern GResource *gedit_docinfo_get_resource (void);
 GResource *gedit_docinfo_get_resource (void)
 {
