@@ -228,7 +228,7 @@ message_set_emblem_cb (GeditMessageBus *bus,
 
 	g_object_get (message, "id", &id, "emblem", &emblem, NULL);
 
-	if (!id || !emblem)
+	if (!id)
 	{
 		g_free (id);
 		g_free (emblem);
@@ -240,46 +240,103 @@ message_set_emblem_cb (GeditMessageBus *bus,
 
 	if (path != NULL)
 	{
-		GError *error = NULL;
-		GdkPixbuf *pixbuf;
+		GtkTreeIter iter;
+		GValue value = G_VALUE_INIT;
+		GdkPixbuf *pixbuf = NULL;
 
-		pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-						   emblem,
-						   10,
-						   0,
-						   &error);
+		if (emblem != NULL)
+		{
+			pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
+			                                   emblem,
+			                                   10,
+			                                   GTK_ICON_LOOKUP_FORCE_SIZE,
+			                                   NULL);
+		}
+
+		store = gedit_file_browser_widget_get_browser_store (data->widget);
+
+		if (gtk_tree_model_get_iter (GTK_TREE_MODEL (store), &iter, path))
+		{
+			g_value_init (&value, GDK_TYPE_PIXBUF);
+			g_value_set_object (&value, pixbuf);
+
+			gedit_file_browser_store_set_value (store,
+			                                    &iter,
+			                                    GEDIT_FILE_BROWSER_STORE_COLUMN_EMBLEM,
+			                                    &value);
+
+			g_value_unset (&value);
+		}
 
 		if (pixbuf)
 		{
-			GValue value = { 0, };
-			GtkTreeIter iter;
-
-			store = gedit_file_browser_widget_get_browser_store (data->widget);
-
-			if (gtk_tree_model_get_iter (GTK_TREE_MODEL (store), &iter, path))
-			{
-				g_value_init (&value, GDK_TYPE_PIXBUF);
-				g_value_set_object (&value, pixbuf);
-
-				gedit_file_browser_store_set_value (store,
-								    &iter,
-								    GEDIT_FILE_BROWSER_STORE_COLUMN_EMBLEM,
-								    &value);
-
-				g_value_unset (&value);
-			}
-
 			g_object_unref (pixbuf);
 		}
-
-		if (error)
-			g_error_free (error);
 	}
 
 	g_free (id);
 	g_free (emblem);
 }
 
+static void
+message_set_markup_cb (GeditMessageBus *bus,
+		       GeditMessage    *message,
+		       WindowData      *data)
+{
+	gchar *id = NULL;
+	gchar *markup = NULL;
+	GtkTreePath *path;
+	GeditFileBrowserStore *store;
+
+	g_object_get (message, "id", &id, "markup", &markup, NULL);
+
+	if (!id)
+	{
+		g_free (id);
+		g_free (markup);
+
+		return;
+	}
+
+	path = track_row_lookup (data, id);
+
+	if (path != NULL)
+	{
+		GtkTreeIter iter;
+		GValue value = G_VALUE_INIT;
+
+		store = gedit_file_browser_widget_get_browser_store (data->widget);
+
+		if (gtk_tree_model_get_iter (GTK_TREE_MODEL (store), &iter, path))
+		{
+			if (markup == NULL)
+			{
+				gchar *name;
+
+				gtk_tree_model_get (GTK_TREE_MODEL (store), &iter,
+				                    GEDIT_FILE_BROWSER_STORE_COLUMN_NAME, &name,
+				                    -1);
+				markup = g_markup_escape_text (name, -1);
+
+				g_free (name);
+			}
+
+			g_value_init (&value, G_TYPE_STRING);
+			g_value_set_string (&value, markup);
+
+			gedit_file_browser_store_set_value (store,
+			                                    &iter,
+			                                    GEDIT_FILE_BROWSER_STORE_COLUMN_MARKUP,
+			                                    &value);
+
+			g_value_unset (&value);
+		}
+	}
+
+	g_free (id);
+	g_free (markup);
+}
+
 static gchar *
 item_id (const gchar *path,
 	 GFile *location)
@@ -322,11 +379,13 @@ set_item_message (WindowData   *data,
 		  GeditMessage *message)
 {
 	GeditFileBrowserStore *store;
+	gchar *name;
 	GFile *location;
 	guint flags = 0;
 
 	store = gedit_file_browser_widget_get_browser_store (data->widget);
 	gtk_tree_model_get (GTK_TREE_MODEL (store), iter,
+			    GEDIT_FILE_BROWSER_STORE_COLUMN_NAME, &name,
 			    GEDIT_FILE_BROWSER_STORE_COLUMN_LOCATION, &location,
 			    GEDIT_FILE_BROWSER_STORE_COLUMN_FLAGS, &flags,
 			    -1);
@@ -349,6 +408,13 @@ set_item_message (WindowData   *data,
 		              "location", location,
 		              NULL);
 
+		if (gedit_message_has (message, "name"))
+		{
+			g_object_set (message,
+			              "name", name,
+			              NULL);
+		}
+
 		if (gedit_message_has (message, "is_directory"))
 		{
 			g_object_set (message,
@@ -360,6 +426,8 @@ set_item_message (WindowData   *data,
 		g_free (track_id);
 		g_object_unref (location);
 	}
+
+	g_free (name);
 }
 
 static gboolean
@@ -593,6 +661,11 @@ register_methods (GeditWindow            *window,
 	                            MESSAGE_OBJECT_PATH,
 	                            "set_emblem");
 
+	gedit_message_bus_register (bus,
+	                            GEDIT_TYPE_FILE_BROWSER_MESSAGE_SET_MARKUP,
+	                            MESSAGE_OBJECT_PATH,
+	                            "set_markup");
+
 	gedit_message_bus_register (bus,
 	                            GEDIT_TYPE_FILE_BROWSER_MESSAGE_ADD_FILTER,
 	                            MESSAGE_OBJECT_PATH,
@@ -651,6 +724,7 @@ register_methods (GeditWindow            *window,
 	BUS_CONNECT (bus, get_root, data);
 	BUS_CONNECT (bus, set_root, data);
 	BUS_CONNECT (bus, set_emblem, data);
+	BUS_CONNECT (bus, set_markup, data);
 	BUS_CONNECT (bus, add_filter, window);
 	BUS_CONNECT (bus, remove_filter, data);
 
@@ -944,6 +1018,7 @@ gedit_file_browser_messages_unregister (GeditWindow *window)
 	BUS_DISCONNECT (bus, get_root, data);
 	BUS_DISCONNECT (bus, set_root, data);
 	BUS_DISCONNECT (bus, set_emblem, data);
+	BUS_DISCONNECT (bus, set_markup, data);
 	BUS_DISCONNECT (bus, add_filter, window);
 	BUS_DISCONNECT (bus, remove_filter, data);
 
