@@ -31,10 +31,6 @@
 #include "gedit-file-browser-marshal.h"
 #include "gedit-file-browser-enum-types.h"
 
-#define GEDIT_FILE_BROWSER_VIEW_GET_PRIVATE(object)( \
-		G_TYPE_INSTANCE_GET_PRIVATE((object), \
-		GEDIT_TYPE_FILE_BROWSER_VIEW, GeditFileBrowserViewPrivate))
-
 struct _GeditFileBrowserViewPrivate
 {
 	GtkTreeViewColumn *column;
@@ -88,7 +84,11 @@ static const GtkTargetEntry drag_source_targets[] = {
 	{ "text/uri-list", 0, 0 }
 };
 
-G_DEFINE_DYNAMIC_TYPE (GeditFileBrowserView, gedit_file_browser_view, GTK_TYPE_TREE_VIEW)
+G_DEFINE_DYNAMIC_TYPE_EXTENDED (GeditFileBrowserView,
+				gedit_file_browser_view,
+				GTK_TYPE_TREE_VIEW,
+				0,
+				G_ADD_PRIVATE_DYNAMIC (GeditFileBrowserView))
 
 static void on_cell_edited 		(GtkCellRendererText    *cell,
 				 	 gchar                  *path,
@@ -970,9 +970,6 @@ gedit_file_browser_view_class_init (GeditFileBrowserViewClass *klass)
 					   bookmark_activated), NULL, NULL,
 			  g_cclosure_marshal_VOID__BOXED,
 			  G_TYPE_NONE, 1, GTK_TYPE_TREE_ITER);
-
-	g_type_class_add_private (object_class,
-				  sizeof (GeditFileBrowserViewPrivate));
 }
 
 static void
@@ -1015,7 +1012,7 @@ cell_data_cb (GtkTreeViewColumn    *tree_column,
 static void
 gedit_file_browser_view_init (GeditFileBrowserView *obj)
 {
-	obj->priv = GEDIT_FILE_BROWSER_VIEW_GET_PRIVATE (obj);
+	obj->priv = gedit_file_browser_view_get_instance_private (obj);
 
 	obj->priv->column = gtk_tree_view_column_new ();
 
