@@ -40,10 +40,6 @@
 #include "gedit-file-browser-marshal.h"
 #include "gedit-file-browser-enum-types.h"
 
-#define GEDIT_FILE_BROWSER_WIDGET_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), \
-						      GEDIT_TYPE_FILE_BROWSER_WIDGET, \
-						      GeditFileBrowserWidgetPrivate))
-
 #define LOCATION_DATA_KEY "gedit-file-browser-widget-location"
 
 enum
@@ -266,7 +262,11 @@ static void set_active_root_activated          (GSimpleAction          *action,
                                                 GVariant               *parameter,
                                                 gpointer                user_data);
 
-G_DEFINE_DYNAMIC_TYPE (GeditFileBrowserWidget, gedit_file_browser_widget, GTK_TYPE_GRID)
+G_DEFINE_DYNAMIC_TYPE_EXTENDED (GeditFileBrowserWidget,
+				gedit_file_browser_widget,
+				GTK_TYPE_GRID,
+				0,
+				G_ADD_PRIVATE_DYNAMIC (GeditFileBrowserWidget))
 
 static void
 free_name_icon (gpointer data)
@@ -556,18 +556,15 @@ gedit_file_browser_widget_class_init (GeditFileBrowserWidgetClass *klass)
 	/* Bind class to template */
 	gtk_widget_class_set_template_from_resource (widget_class,
 	                                             "/org/gnome/gedit/plugins/file-browser/ui/gedit-file-browser-widget.ui");
-	gtk_widget_class_bind_child (widget_class, GeditFileBrowserWidgetPrivate, previous_button);
-	gtk_widget_class_bind_child (widget_class, GeditFileBrowserWidgetPrivate, next_button);
-	gtk_widget_class_bind_child (widget_class, GeditFileBrowserWidgetPrivate, combo);
-	gtk_widget_class_bind_child (widget_class, GeditFileBrowserWidgetPrivate, combo_model);
-	gtk_widget_class_bind_child (widget_class, GeditFileBrowserWidgetPrivate, location_entry);
-	gtk_widget_class_bind_child (widget_class, GeditFileBrowserWidgetPrivate, treeview);
-	gtk_widget_class_bind_child (widget_class, GeditFileBrowserWidgetPrivate, filter_entry);
-	gtk_widget_class_bind_child (widget_class, GeditFileBrowserWidgetPrivate, location_previous_menu);
-	gtk_widget_class_bind_child (widget_class, GeditFileBrowserWidgetPrivate, location_next_menu);
-
-	g_type_class_add_private (object_class,
-				  sizeof (GeditFileBrowserWidgetPrivate));
+	gtk_widget_class_bind_template_child_private (widget_class, GeditFileBrowserWidget, previous_button);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditFileBrowserWidget, next_button);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditFileBrowserWidget, combo);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditFileBrowserWidget, combo_model);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditFileBrowserWidget, location_entry);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditFileBrowserWidget, treeview);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditFileBrowserWidget, filter_entry);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditFileBrowserWidget, location_previous_menu);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditFileBrowserWidget, location_next_menu);
 }
 
 static void
@@ -954,7 +951,7 @@ gedit_file_browser_widget_init (GeditFileBrowserWidget *obj)
 	GAction *action;
 	GError *error = NULL;
 
-	obj->priv = GEDIT_FILE_BROWSER_WIDGET_GET_PRIVATE (obj);
+	obj->priv = gedit_file_browser_widget_get_instance_private (obj);
 
 	obj->priv->filter_pattern_str = g_strdup ("");
 	obj->priv->bookmarks_hash = g_hash_table_new_full (g_file_hash,
