@@ -68,7 +68,7 @@ class QuickOpenPlugin(GObject.Object, Gedit.WindowActivatable):
         manager = self.window.get_ui_manager()
         self._action_group = Gtk.ActionGroup(name="GeditQuickOpenPluginActions")
         self._action_group.add_actions([
-            ("QuickOpen", Gtk.STOCK_OPEN, _("Quick open"),
+            ("QuickOpen", Gtk.STOCK_OPEN, _("Quick Open..."),
              '<Primary><Alt>o', _("Quickly open documents"),
              self.on_quick_open_activate)
         ])
@@ -126,7 +126,7 @@ class QuickOpenPlugin(GObject.Object, Gedit.WindowActivatable):
         self._popup.connect('destroy', self.on_popup_destroy)
 
     def _local_bookmarks(self):
-        filename = os.path.expanduser('~/.gtk-bookmarks')
+        filename = os.path.expanduser('~/.config/gtk-3.0/bookmarks')
 
         if not os.path.isfile(filename):
             return []
