@@ -109,9 +109,9 @@ class Provider(GObject.Object, GtkSource.CompletionProvider):
 
                 # Filter based on the current word
                 if word:
-                        proposals = filter(lambda x: x['tag'].startswith(word), proposals)
+                        proposals = (x for x in proposals if x['tag'].startswith(word))
 
-                return list(map(lambda x: Proposal(x), proposals))
+                return [Proposal(x) for x in proposals]
 
         def do_populate(self, context):
                 proposals = self.get_proposals(self.get_word(context))
