@@ -437,9 +437,9 @@ class PlaceholderShell(PlaceholderExpand):
 
                         if len(line) > 0:
                                 try:
-                                        line = line
-                                except:
-                                        line = line.encode(locale.getdefaultlocale()[1])
+                                        line = line.decode('utf-8')
+                                except UnicodeDecodeError:
+                                        line = line.decode(locale.getdefaultlocale()[1], errors='replace')
 
                                 self.shell_output += line
                                 self.install_timeout()
@@ -571,7 +571,7 @@ class PlaceholderEval(PlaceholderExpand):
                         self.set_text('')
                         return
 
-                text = "def process_snippet():\n\t" + u"\n\t".join(text.split("\n"))
+                text = "def process_snippet():\n\t" + "\n\t".join(text.split("\n"))
 
                 if 'process_snippet' in self.namespace:
                         del self.namespace['process_snippet']
