@@ -1815,7 +1815,7 @@ static const SECTION union { const guint8 data[14444]; const double alignment; v
   0x03, 0x00, 0x00, 0x00
 } };
 
-static GStaticResource static_resource = { gedit_time_resource_data.data, sizeof (gedit_time_resource_data.data) };
+static GStaticResource static_resource = { gedit_time_resource_data.data, sizeof (gedit_time_resource_data.data), NULL, NULL, NULL };
 extern GResource *gedit_time_get_resource (void);
 GResource *gedit_time_get_resource (void)
 {
