@@ -186,16 +186,19 @@ gedit_zeitgeist_plugin_send_event (GeditZeitgeistPlugin *plugin,
 		event = zeitgeist_event_new_full (interpretation,
 		                                  ZEITGEIST_ZG_USER_ACTIVITY,
 		                                  "application://gedit.desktop",
+		                                  NULL,
 		                                  subject,
 		                                  NULL);
 
-		zeitgeist_log_insert_events_no_reply (zg_log, event, NULL);
+		zeitgeist_log_insert_event_no_reply (zg_log, event, NULL);
 
 		g_free (display_name);
 		g_free (mime_type);
 		g_free (dir_name);
 		g_free (doc_uri);
 
+		g_object_unref (event);
+		g_object_unref (subject);
 		g_object_unref (location);
 	}
 }
@@ -273,7 +276,7 @@ gedit_zeitgeist_plugin_app_activate (GeditAppActivatable *activatable)
 	zg_log = zeitgeist_log_new ();
 
 	event = zeitgeist_event_new_full (NULL, NULL,
-	                                  "application://gedit.desktop", NULL);
+	                                  "application://gedit.desktop", NULL, NULL);
 	ptr_arr = g_ptr_array_new ();
 	g_ptr_array_add (ptr_arr, event);
 
@@ -285,6 +288,8 @@ gedit_zeitgeist_plugin_app_activate (GeditAppActivatable *activatable)
 	zg_dsr = zeitgeist_data_source_registry_new ();
 	zeitgeist_data_source_registry_register_data_source (zg_dsr, ds,
 	                                                     NULL, NULL, NULL);
+	g_ptr_array_set_free_func (ptr_arr, g_object_unref);
+	g_ptr_array_unref (ptr_arr);
 }
 
 static void
